@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
 # This file is part of the pnopaste program
-# Copyright (C) 2008-2013 Patrick Matthäi <pmatthaei@debian.org>
+# Copyright (C) 2008-2016 Patrick Matthäi <pmatthaei@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,6 +11,8 @@
 use warnings;
 no warnings 'once';
 use strict;
+use Cwd;
+use lib cwd;
 use CGI qw/:standard/;
 use lib::Code;
 use lib::HTML;
