@@ -4,7 +4,7 @@ CREATE TABLE `blacklist_ip` (
   `hits` int(11) NOT NULL default '0',
   PRIMARY KEY  (`id`),
   KEY `ip` (`ip`)
-) ENGINE=MyISAM ;
+) ;
 
 CREATE TABLE `blacklist_word` (
   `id` int(11) NOT NULL auto_increment,
@@ -12,13 +12,13 @@ CREATE TABLE `blacklist_word` (
   `hits` int(11) NOT NULL default '0',
   PRIMARY KEY  (`id`),
   KEY `word` (`word`)
-) ENGINE=MyISAM ;
+) ;
 
 CREATE TABLE `nopaste` (
   `id` int(11) NOT NULL auto_increment,
   `name` varchar(100) NOT NULL default '',
   `description` text NOT NULL,
-  `code` text NOT NULL,
+  `code` mediumtext,
   `language` text NOT NULL,
   `time` int(15) NOT NULL default '0',
   `ip` varchar(20) NOT NULL,
@@ -26,7 +26,7 @@ CREATE TABLE `nopaste` (
   PRIMARY KEY  (`id`),
   KEY `time` (`time`),
   KEY `expires` (`expires`)
-) ENGINE=MyISAM ;
+) ;
 
 CREATE TABLE `settings` (
   `username` VARCHAR(100) NOT NULL default 'admin',
@@ -37,5 +37,5 @@ CREATE TABLE `settings` (
   `title` VARCHAR(150) NOT NULL default 'Perl NoPaste Service',
   `style` VARCHAR(20) NOT NULL default 'default',
   `language` VARCHAR(2)  NOT NULL default 'en'
-) ENGINE=MyISAM ;
+) ;
 
